@@ -25,16 +25,16 @@ def getdays(number=3):
     '''
     获取所需日期数量列表，默认3个月内
     Get the required date quantity list, within 3 months by default
-    :param number: 生成的月数 Number of months generated
+    :param number: Number of months generated
     :return: list
     '''
-    days_list = getcurrent_monthsurplusdays()
+    days_list = getcurrent_days()
     for i in range(1, number + 1):
-        days_list += getnextmonth_surplusdays(next_months=i)
+        days_list += getnext_days(next_months=i)
     return days_list
 
 
-def getcurrent_monthsurplusdays(current_date=None):
+def getcurrent_days(current_date=None):
     '''
     获取指定月的剩余天数，
     current_date为空时，则获取本月剩余天数
@@ -64,7 +64,7 @@ def getcurrent_monthsurplusdays(current_date=None):
     return c_list
 
 
-def getnextmonth_surplusdays(current_date=None, next_months=1):
+def getnext_days(current_date=None, next_months=1):
     '''
     返回下个月日期列表 (自动跨年)
     Return to the next month date list (automatically cross year)
@@ -92,11 +92,3 @@ def getnextmonth_surplusdays(current_date=None, next_months=1):
         s_date = f'{n_year}-{s_month}-{s_day}'
         n_list.append(s_date)
     return n_list
-
-
-'''
-测试/test
-print(getdays())
-print(getcurrent_monthsurplusdays('2023-08-05'))
-print(getnextmonth_surplusdays())
-'''
